==========================
Joyous 1.3.0 release notes
==========================

.. contents::
    :local:
    :depth: 3


What's new
==========

Option for compatibility with wagtail-modeltranslations
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This release adds new setting :setting:`JOYOUS_DEFEND_FORMS`.
If this is set to ``True`` then the Joyous page models will not allow
their base_form_class to be replaced.  Instead they will assimilate
the newly assigned form class.
The purpose of this setting is to make Joyous compatible with the
`wagtail-modeltranslations <https://github.com/infoportugal/wagtail-modeltranslation>`_ app.  
If you do not use wagtail-modeltranslations then you probably do not need
to enable this option.

Wagtail 2.10
~~~~~~~~~~~~~
 * Use Django Admin version of JQuery

Other features
~~~~~~~~~~~~~~

Bug fixes
~~~~~~~~~


Upgrade considerations
======================

